@@ -172,8 +172,10 @@ class Anonymiser:
         If only text is provided, the anonymised text is returned.
         """
         if self.num_runs > 1:
-            self.logger.warning("It appears you are sequentially running the model. Reccomended: Pass 'dataset' to the class.")
-            
+            self.logger.warning(
+                "It appears you are sequentially running the model. Reccomended: Pass 'dataset' to the class."
+            )
+
         if dataset is None:
             dataset = self.dataset
         if text is not None:
