@@ -187,7 +187,7 @@ class Anonymiser:
     def anonymise(
         self,
         text: str = None,
-        dataset: str = None) -> None:
+        dataset: str = None) -> Optional[str]:
         self.logger.info("Anonymising text data. n.b 'anonymise' method overwrites the text column.")
         self._run(
             text=text, dataset=dataset, replace=True)
\ No newline at end of file
