@@ -40,9 +40,9 @@ class CustomFormatter(logging.Formatter):
 class ColoredFormatter(CustomFormatter):
     COLORS = {
         "DEBUG": "\033[94m",  # Blue
-        "  INFO ": "\033[1;97m", # White
+        "INFO": "\033[0m",
         "WARNING": "\033[93m",  # Yellow
-        " ERROR ": "\033[1;91m",  # Red
+        " ERROR ": "\033[91m",  # Red
         "CRITICAL": "\033[95m",  # Magenta
         "RESET": "\033[0m",
     }
